@@ -48,8 +48,8 @@ class ScoreComponentFactory:
             enum.SA_SCORE: SASComponent,
             enum.AZDOCK: AZdock,
             enum.AZ_LOGD74_PIP: PiPPredictionComponent,
-            enum.CACO2_INTR_PIP: PiPPredictionComponent,
-            enum.CACO2_EFFLUX_PIP: PiPLogPredictionComponent,
+            enum.CACO2_INTR_PIP: PiPLogPredictionComponent,
+            enum.CACO2_EFFLUX_PIP: PiPPredictionComponent,
             enum.HH_CLINT_PIP: PiPLogPredictionComponent,
             enum.HLM_CLINT_PIP: PiPLogPredictionComponent,
             enum.RH_CLINT_PIP: PiPLogPredictionComponent,
